Rotor design tools
==================

These pages demonstrates how to generate a wind turbine rotor design (e.g. blade design) given a baseline design as well as a 
given set of design conditions that are different than the baseline design.


.. toctree::
   :maxdepth: 2

   aero_design
   structural_scaling
   rotor_utils